import { APIClient } from '../api.ts';
import { type OAuthClientCreateData, type OAuthClientCreateRequest, type OAuthClientListItem, type OAuthClientUpdateData, type OAuthClientUpdateRequest, type OAuthConsentGrant, type OAuthRotateSecretData } from './types.ts';
export declare function oauthClientList(client: APIClient): Promise<OAuthClientListItem[]>;
export declare function oauthClientGet(client: APIClient, id: string): Promise<OAuthClientListItem>;
export declare function oauthClientCreate(client: APIClient, request: OAuthClientCreateRequest): Promise<OAuthClientCreateData>;
export declare function oauthClientUpdate(client: APIClient, id: string, request: OAuthClientUpdateRequest): Promise<OAuthClientUpdateData>;
export declare function oauthClientDelete(client: APIClient, id: string): Promise<{
    deleted: true;
}>;
export declare function oauthClientRotateSecret(client: APIClient, id: string): Promise<OAuthRotateSecretData>;
export declare function oauthClientUsers(client: APIClient, id: string): Promise<OAuthConsentGrant[]>;
export declare function oauthClientRevokeAllUsers(client: APIClient, id: string): Promise<{
    deleted: true;
}>;
export declare function oauthClientRevokeUser(client: APIClient, id: string, userId: string): Promise<{
    deleted: true;
}>;
//# sourceMappingURL=clients.d.ts.map