import { StructuredError } from '../../error.ts';

export const BucketConfigResponseError = StructuredError('BucketConfigResponseError');
export const StorageObjectsResponseError = StructuredError('StorageObjectsResponseError');
