import { z } from 'zod';
/** Single region info (matches API response shape) */
export declare const RegionInfoApiSchema: z.ZodObject<{
    region: z.ZodString;
    description: z.ZodString;
}, z.core.$strip>;
export type RegionInfoApi = z.infer<typeof RegionInfoApiSchema>;
/** Request body for POST /resource/{orgId}/{region} (create resources) */
export declare const CreateResourcesApiRequestSchema: z.ZodObject<{
    resources: z.ZodArray<z.ZodAny>;
}, z.core.$strip>;
export type CreateResourcesApiRequest = z.infer<typeof CreateResourcesApiRequestSchema>;
/** Request body for DELETE /resource/{orgId}/{region} (delete resources) */
export declare const DeleteResourcesApiRequestSchema: z.ZodObject<{
    resources: z.ZodArray<z.ZodAny>;
}, z.core.$strip>;
export type DeleteResourcesApiRequest = z.infer<typeof DeleteResourcesApiRequestSchema>;
//# sourceMappingURL=types.d.ts.map