import { z } from 'zod';
/**
 * Response schema for the update-schedule endpoint.
 */
export declare const ScheduleUpdateResultSchema: z.ZodObject<{
    schedule: z.ZodObject<{
        id: z.ZodString;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        created_by: z.ZodString;
        name: z.ZodString;
        description: z.ZodNullable<z.ZodString>;
        expression: z.ZodString;
        due_date: z.ZodString;
        internal: z.ZodBoolean;
    }, z.core.$strip>;
}, z.core.$strip>;
export type ScheduleUpdateResult = z.infer<typeof ScheduleUpdateResultSchema>;
/**
 * Response schema for the create-schedule-destination endpoint.
 */
export declare const ScheduleCreateDestinationResultSchema: z.ZodObject<{
    destination: z.ZodObject<{
        id: z.ZodString;
        schedule_id: z.ZodString;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        created_by: z.ZodString;
        type: z.ZodEnum<{
            url: "url";
            sandbox: "sandbox";
        }>;
        config: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    }, z.core.$strip>;
}, z.core.$strip>;
export type ScheduleCreateDestinationResult = z.infer<typeof ScheduleCreateDestinationResultSchema>;
//# sourceMappingURL=types.d.ts.map