/**
 * Safe environment variable accessor that works in both browser and server environments.
 */
export function getEnv(key) {
    if (typeof process !== 'undefined' && process.env) {
        return process.env[key];
    }
    return undefined;
}
//# sourceMappingURL=env.js.map