/**
 * Safely stringify an object to JSON, handling circular references
 * @param obj - The object to stringify
 * @returns JSON string representation
 */
export declare function safeStringify(obj: unknown, space?: number | string): string;
//# sourceMappingURL=json.d.ts.map