import { APIClient } from '../api.ts';
import { type OAuthScopesData } from './types.ts';
export declare function oauthScopes(client: APIClient): Promise<OAuthScopesData>;
//# sourceMappingURL=scopes.d.ts.map