import { z } from 'zod';
/**
 * Request body schema for creating a comment on a task.
 */
export declare const CreateCommentRequestSchema: z.ZodObject<{
    body: z.ZodString;
    user_id: z.ZodString;
}, z.core.$strip>;
export type CreateCommentRequest = z.infer<typeof CreateCommentRequestSchema>;
/**
 * Request body schema for updating a comment.
 */
export declare const UpdateCommentRequestSchema: z.ZodObject<{
    body: z.ZodString;
}, z.core.$strip>;
export type UpdateCommentRequest = z.infer<typeof UpdateCommentRequestSchema>;
/**
 * Request body schema for creating a tag.
 */
export declare const CreateTagRequestSchema: z.ZodObject<{
    name: z.ZodString;
    color: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CreateTagRequest = z.infer<typeof CreateTagRequestSchema>;
/**
 * Request body schema for updating a tag.
 */
export declare const UpdateTagRequestSchema: z.ZodObject<{
    name: z.ZodString;
    color: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type UpdateTagRequest = z.infer<typeof UpdateTagRequestSchema>;
/**
 * Request body schema for creating a user entity.
 */
export declare const CreateTaskUserRequestSchema: z.ZodObject<{
    name: z.ZodString;
    type: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CreateTaskUserRequest = z.infer<typeof CreateTaskUserRequestSchema>;
/**
 * Request body schema for creating a project entity.
 */
export declare const CreateTaskProjectRequestSchema: z.ZodObject<{
    name: z.ZodString;
}, z.core.$strip>;
export type CreateTaskProjectRequest = z.infer<typeof CreateTaskProjectRequestSchema>;
//# sourceMappingURL=types.d.ts.map