import { z } from 'zod';
import { type APIClient } from '../api.ts';
export declare const DbLogStatsRequestSchema: z.ZodObject<{
    database: z.ZodString;
    orgId: z.ZodString;
    region: z.ZodString;
    startDate: z.ZodString;
    endDate: z.ZodString;
}, z.core.$strip>;
export declare const DbLogStatsSummarySchema: z.ZodObject<{
    totalQueries: z.ZodNumber;
    errorCount: z.ZodNumber;
    avgDuration: z.ZodNumber;
    p50Duration: z.ZodNumber;
    p95Duration: z.ZodNumber;
    p99Duration: z.ZodNumber;
    maxDuration: z.ZodNumber;
    totalRows: z.ZodNumber;
}, z.core.$strip>;
export declare const DbLogStatsTimeSeriesPointSchema: z.ZodObject<{
    timestamp: z.ZodString;
    queryCount: z.ZodNumber;
    errorCount: z.ZodNumber;
    avgDuration: z.ZodNumber;
    p50Duration: z.ZodNumber;
    p95Duration: z.ZodNumber;
    p99Duration: z.ZodNumber;
}, z.core.$strip>;
export declare const DbLogStatsQueryPatternSchema: z.ZodObject<{
    pattern: z.ZodString;
    command: z.ZodString;
    calls: z.ZodNumber;
    avgDuration: z.ZodNumber;
    p95Duration: z.ZodNumber;
    maxDuration: z.ZodNumber;
    totalDuration: z.ZodNumber;
    avgRows: z.ZodNumber;
    errors: z.ZodNumber;
}, z.core.$strip>;
export declare const DbLogStatsCommandBreakdownSchema: z.ZodObject<{
    command: z.ZodString;
    queryCount: z.ZodNumber;
    avgDuration: z.ZodNumber;
    p95Duration: z.ZodNumber;
    totalDuration: z.ZodNumber;
    errorCount: z.ZodNumber;
}, z.core.$strip>;
export declare const DbLogStatsResponseSchema: z.ZodObject<{
    summary: z.ZodObject<{
        totalQueries: z.ZodNumber;
        errorCount: z.ZodNumber;
        avgDuration: z.ZodNumber;
        p50Duration: z.ZodNumber;
        p95Duration: z.ZodNumber;
        p99Duration: z.ZodNumber;
        maxDuration: z.ZodNumber;
        totalRows: z.ZodNumber;
    }, z.core.$strip>;
    timeSeries: z.ZodArray<z.ZodObject<{
        timestamp: z.ZodString;
        queryCount: z.ZodNumber;
        errorCount: z.ZodNumber;
        avgDuration: z.ZodNumber;
        p50Duration: z.ZodNumber;
        p95Duration: z.ZodNumber;
        p99Duration: z.ZodNumber;
    }, z.core.$strip>>;
    queryPatterns: z.ZodArray<z.ZodObject<{
        pattern: z.ZodString;
        command: z.ZodString;
        calls: z.ZodNumber;
        avgDuration: z.ZodNumber;
        p95Duration: z.ZodNumber;
        maxDuration: z.ZodNumber;
        totalDuration: z.ZodNumber;
        avgRows: z.ZodNumber;
        errors: z.ZodNumber;
    }, z.core.$strip>>;
    commandBreakdown: z.ZodArray<z.ZodObject<{
        command: z.ZodString;
        queryCount: z.ZodNumber;
        avgDuration: z.ZodNumber;
        p95Duration: z.ZodNumber;
        totalDuration: z.ZodNumber;
        errorCount: z.ZodNumber;
    }, z.core.$strip>>;
}, z.core.$strip>;
export declare const DbLogStatsAPIResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        summary: z.ZodObject<{
            totalQueries: z.ZodNumber;
            errorCount: z.ZodNumber;
            avgDuration: z.ZodNumber;
            p50Duration: z.ZodNumber;
            p95Duration: z.ZodNumber;
            p99Duration: z.ZodNumber;
            maxDuration: z.ZodNumber;
            totalRows: z.ZodNumber;
        }, z.core.$strip>;
        timeSeries: z.ZodArray<z.ZodObject<{
            timestamp: z.ZodString;
            queryCount: z.ZodNumber;
            errorCount: z.ZodNumber;
            avgDuration: z.ZodNumber;
            p50Duration: z.ZodNumber;
            p95Duration: z.ZodNumber;
            p99Duration: z.ZodNumber;
        }, z.core.$strip>>;
        queryPatterns: z.ZodArray<z.ZodObject<{
            pattern: z.ZodString;
            command: z.ZodString;
            calls: z.ZodNumber;
            avgDuration: z.ZodNumber;
            p95Duration: z.ZodNumber;
            maxDuration: z.ZodNumber;
            totalDuration: z.ZodNumber;
            avgRows: z.ZodNumber;
            errors: z.ZodNumber;
        }, z.core.$strip>>;
        commandBreakdown: z.ZodArray<z.ZodObject<{
            command: z.ZodString;
            queryCount: z.ZodNumber;
            avgDuration: z.ZodNumber;
            p95Duration: z.ZodNumber;
            totalDuration: z.ZodNumber;
            errorCount: z.ZodNumber;
        }, z.core.$strip>>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export type DbLogStatsSummary = z.infer<typeof DbLogStatsSummarySchema>;
export type DbLogStatsTimeSeriesPoint = z.infer<typeof DbLogStatsTimeSeriesPointSchema>;
export type DbLogStatsQueryPattern = z.infer<typeof DbLogStatsQueryPatternSchema>;
export type DbLogStatsCommandBreakdown = z.infer<typeof DbLogStatsCommandBreakdownSchema>;
export type DbLogStatsResponse = z.infer<typeof DbLogStatsResponseSchema>;
type DbLogStatsRequest = z.infer<typeof DbLogStatsRequestSchema>;
/**
 * Get query performance stats for a database
 */
export declare function dbLogStats(client: APIClient, request: DbLogStatsRequest): Promise<DbLogStatsResponse>;
export {};
//# sourceMappingURL=stats.d.ts.map