import { z } from 'zod';
/** API-level request for creating a namespace (uses snake_case field names) */
export declare const CreateNamespaceApiRequestSchema: z.ZodObject<{
    default_ttl_seconds: z.ZodOptional<z.ZodNumber>;
}, z.core.$strip>;
/** Metadata for a key-value item in search results */
export declare const KeyValueItemMetadataSchema: z.ZodObject<{
    value: z.ZodUnknown;
    contentType: z.ZodString;
    size: z.ZodNumber;
    expiresAt: z.ZodNullable<z.ZodString>;
    firstUsed: z.ZodNullable<z.ZodNumber>;
    lastUsed: z.ZodNullable<z.ZodNumber>;
    count: z.ZodNullable<z.ZodNumber>;
}, z.core.$strip>;
export type CreateNamespaceApiRequest = z.infer<typeof CreateNamespaceApiRequestSchema>;
export type KeyValueItemMetadata = z.infer<typeof KeyValueItemMetadataSchema>;
//# sourceMappingURL=types.d.ts.map