import { type APIClient } from '../api.ts';
import { type CoderCreateWorkspaceRequest, type CoderUpdateWorkspaceRequest, type CoderWorkspaceDependencyValidationResponse, type CoderWorkspaceDetail, type CoderWorkspaceListResponse } from './types.ts';
export declare function coderListWorkspaces(client: APIClient): Promise<CoderWorkspaceListResponse>;
export declare function coderGetWorkspace(client: APIClient, params: {
    workspaceId: string;
}): Promise<CoderWorkspaceDetail>;
export declare function coderCreateWorkspace(client: APIClient, params: {
    body: CoderCreateWorkspaceRequest;
}): Promise<CoderWorkspaceDetail>;
export declare function coderUpdateWorkspace(client: APIClient, params: {
    workspaceId: string;
    body: CoderUpdateWorkspaceRequest;
}): Promise<CoderWorkspaceDetail>;
export declare function coderRefreshWorkspaceSnapshot(client: APIClient, params: {
    workspaceId: string;
}): Promise<CoderWorkspaceDetail>;
export declare function coderValidateWorkspaceDependencies(client: APIClient, params: {
    dependencies: string[];
}): Promise<CoderWorkspaceDependencyValidationResponse>;
export declare function coderDeleteWorkspace(client: APIClient, params: {
    workspaceId: string;
}): Promise<void>;
//# sourceMappingURL=workspaces.d.ts.map