import type { z as zType } from 'zod';
import { z } from 'zod';
import { type APIClient } from '../api.ts';
export declare const DiskCheckpointInfoSchema: zType.ZodObject<{
    id: zType.ZodString;
    name: zType.ZodString;
    createdAt: zType.ZodString;
    parent: zType.ZodString;
}, zType.core.$strip>;
export type DiskCheckpointInfo = z.infer<typeof DiskCheckpointInfoSchema>;
export declare const CreateDiskCheckpointResponseSchema: zType.ZodDiscriminatedUnion<[zType.ZodObject<{
    success: zType.ZodLiteral<false>;
    message: zType.ZodString;
    code: zType.ZodOptional<zType.ZodString>;
}, zType.core.$strip>, zType.ZodObject<{
    success: zType.ZodLiteral<true>;
    data: zType.ZodObject<{
        id: zType.ZodString;
        name: zType.ZodString;
        createdAt: zType.ZodString;
        parent: zType.ZodString;
    }, zType.core.$strip>;
}, zType.core.$strip>], "success">;
export declare const ListDiskCheckpointsResponseSchema: zType.ZodDiscriminatedUnion<[zType.ZodObject<{
    success: zType.ZodLiteral<false>;
    message: zType.ZodString;
    code: zType.ZodOptional<zType.ZodString>;
}, zType.core.$strip>, zType.ZodObject<{
    success: zType.ZodLiteral<true>;
    data: zType.ZodObject<{
        checkpoints: zType.ZodArray<zType.ZodObject<{
            id: zType.ZodString;
            name: zType.ZodString;
            createdAt: zType.ZodString;
            parent: zType.ZodString;
        }, zType.core.$strip>>;
    }, zType.core.$strip>;
}, zType.core.$strip>], "success">;
export declare const RestoreDiskCheckpointResponseSchema: zType.ZodDiscriminatedUnion<[zType.ZodObject<{
    success: zType.ZodLiteral<false>;
    message: zType.ZodString;
    code: zType.ZodOptional<zType.ZodString>;
}, zType.core.$strip>, zType.ZodObject<{
    success: zType.ZodLiteral<true>;
}, zType.core.$strip>], "success">;
export declare const DeleteDiskCheckpointResponseSchema: zType.ZodDiscriminatedUnion<[zType.ZodObject<{
    success: zType.ZodLiteral<false>;
    message: zType.ZodString;
    code: zType.ZodOptional<zType.ZodString>;
}, zType.core.$strip>, zType.ZodObject<{
    success: zType.ZodLiteral<true>;
}, zType.core.$strip>], "success">;
export declare const DiskCheckpointCreateParamsSchema: zType.ZodObject<{
    sandboxId: zType.ZodString;
    name: zType.ZodString;
    orgId: zType.ZodOptional<zType.ZodString>;
}, zType.core.$strip>;
export declare const DiskCheckpointListParamsSchema: zType.ZodObject<{
    sandboxId: zType.ZodString;
    orgId: zType.ZodOptional<zType.ZodString>;
}, zType.core.$strip>;
export declare const DiskCheckpointRestoreParamsSchema: zType.ZodObject<{
    sandboxId: zType.ZodString;
    checkpointId: zType.ZodString;
    orgId: zType.ZodOptional<zType.ZodString>;
}, zType.core.$strip>;
export declare const DiskCheckpointDeleteParamsSchema: zType.ZodObject<{
    sandboxId: zType.ZodString;
    checkpointId: zType.ZodString;
    orgId: zType.ZodOptional<zType.ZodString>;
}, zType.core.$strip>;
export type DiskCheckpointCreateParams = z.infer<typeof DiskCheckpointCreateParamsSchema>;
export type DiskCheckpointListParams = z.infer<typeof DiskCheckpointListParamsSchema>;
export type DiskCheckpointRestoreParams = z.infer<typeof DiskCheckpointRestoreParamsSchema>;
export type DiskCheckpointDeleteParams = z.infer<typeof DiskCheckpointDeleteParamsSchema>;
/**
 * Creates a new disk checkpoint for a sandbox.
 *
 * @param client - The API client to use for the request
 * @param params - Parameters including the sandbox ID and checkpoint name
 * @throws {SandboxResponseError} If the sandbox is not found or checkpoint creation fails
 */
export declare function diskCheckpointCreate(client: APIClient, params: DiskCheckpointCreateParams): Promise<DiskCheckpointInfo>;
/**
 * Lists all disk checkpoints for a sandbox.
 *
 * @param client - The API client to use for the request
 * @param params - Parameters including the sandbox ID
 * @throws {SandboxResponseError} If the sandbox is not found or listing fails
 */
export declare function diskCheckpointList(client: APIClient, params: DiskCheckpointListParams): Promise<DiskCheckpointInfo[]>;
/**
 * Restores a sandbox to a specific disk checkpoint.
 *
 * @param client - The API client to use for the request
 * @param params - Parameters including the sandbox ID and checkpoint ID
 * @throws {SandboxResponseError} If the sandbox or checkpoint is not found, or restore fails
 */
export declare function diskCheckpointRestore(client: APIClient, params: DiskCheckpointRestoreParams): Promise<void>;
/**
 * Deletes a disk checkpoint from a sandbox.
 *
 * @param client - The API client to use for the request
 * @param params - Parameters including the sandbox ID and checkpoint ID
 * @throws {SandboxResponseError} If the sandbox or checkpoint is not found, or deletion fails
 */
export declare function diskCheckpointDelete(client: APIClient, params: DiskCheckpointDeleteParams): Promise<void>;
//# sourceMappingURL=disk-checkpoint.d.ts.map