import { z } from 'zod';
export declare const ServiceExceptionPayloadSchema: z.ZodObject<{
    statusCode: z.ZodNumber;
    method: z.ZodEnum<{
        GET: "GET";
        PUT: "PUT";
        POST: "POST";
        DELETE: "DELETE";
        HEAD: "HEAD";
        OPTIONS: "OPTIONS";
        PATCH: "PATCH";
    }>;
    url: z.ZodString;
    sessionId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, z.core.$strip>;
export type ServiceExceptionPayload = z.infer<typeof ServiceExceptionPayloadSchema>;
export declare const ServiceException: {
    new (args?: ({
        statusCode: number;
        method: "GET" | "PUT" | "POST" | "DELETE" | "HEAD" | "OPTIONS" | "PATCH";
        url: string;
        sessionId?: string | null | undefined;
    } & {
        message?: string;
        cause?: unknown;
    }) | undefined): import("../error.ts").RichError & {
        readonly _tag: "ServiceException";
    } & Readonly<{
        statusCode: number;
        method: "GET" | "PUT" | "POST" | "DELETE" | "HEAD" | "OPTIONS" | "PATCH";
        url: string;
        sessionId?: string | null | undefined;
    }>;
    readonly defaultMessage?: string;
};
//# sourceMappingURL=exception.d.ts.map