import { APIClient } from '../api.ts';
import { type OAuthBulkActivityItem, type OAuthClientActivityItem } from './types.ts';
export declare function oauthClientActivity(client: APIClient, id: string, days?: number): Promise<OAuthClientActivityItem[]>;
export declare function oauthBulkActivity(client: APIClient, days?: number): Promise<OAuthBulkActivityItem[]>;
//# sourceMappingURL=activity.d.ts.map