import { StructuredError } from "../../error.js";
export const BucketConfigResponseError = StructuredError('BucketConfigResponseError');
export const StorageObjectsResponseError = StructuredError('StorageObjectsResponseError');
//# sourceMappingURL=util.js.map