import { z } from 'zod';
/** Basic organization info returned in list endpoints */
export declare const OrgInfoApiSchema: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
}, z.core.$strip>;
export type OrgInfo = z.infer<typeof OrgInfoApiSchema>;
//# sourceMappingURL=types.d.ts.map