import { StructuredError } from "../../error.js";
export const OrgResponseError = StructuredError('OrgResponseError');
export const OrgResourceResponseError = StructuredError('OrgResourceResponseError');
//# sourceMappingURL=util.js.map