import { z } from 'zod';
import { APIClient } from '../api.ts';
declare const SessionSchema: z.ZodObject<{
    id: z.ZodString;
    created_at: z.ZodString;
    updated_at: z.ZodString;
    deleted: z.ZodBoolean;
    deleted_at: z.ZodNullable<z.ZodString>;
    deleted_by: z.ZodNullable<z.ZodString>;
    start_time: z.ZodString;
    end_time: z.ZodNullable<z.ZodString>;
    duration: z.ZodNullable<z.ZodNumber>;
    org_id: z.ZodString;
    project_id: z.ZodString;
    deployment_id: z.ZodString;
    agent_ids: z.ZodArray<z.ZodString>;
    trigger: z.ZodString;
    env: z.ZodString;
    devmode: z.ZodBoolean;
    pending: z.ZodBoolean;
    success: z.ZodBoolean;
    error: z.ZodNullable<z.ZodString>;
    metadata: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>>;
    cpu_time: z.ZodNullable<z.ZodNumber>;
    llm_cost: z.ZodNullable<z.ZodNumber>;
    llm_prompt_token_count: z.ZodNullable<z.ZodNumber>;
    llm_completion_token_count: z.ZodNullable<z.ZodNumber>;
    total_cost: z.ZodNullable<z.ZodNumber>;
    method: z.ZodNullable<z.ZodString>;
    url: z.ZodNullable<z.ZodString>;
    route_id: z.ZodNullable<z.ZodString>;
    thread_id: z.ZodNullable<z.ZodString>;
    timeline: z.ZodOptional<z.ZodNullable<z.ZodUnknown>>;
    user_data: z.ZodOptional<z.ZodNullable<z.ZodString>>;
}, z.core.$strip>;
export { SessionSchema };
export declare const SessionListResponse: z.ZodArray<z.ZodObject<{
    id: z.ZodString;
    created_at: z.ZodString;
    updated_at: z.ZodString;
    deleted: z.ZodBoolean;
    deleted_at: z.ZodNullable<z.ZodString>;
    deleted_by: z.ZodNullable<z.ZodString>;
    start_time: z.ZodString;
    end_time: z.ZodNullable<z.ZodString>;
    duration: z.ZodNullable<z.ZodNumber>;
    org_id: z.ZodString;
    project_id: z.ZodString;
    deployment_id: z.ZodString;
    agent_ids: z.ZodArray<z.ZodString>;
    trigger: z.ZodString;
    env: z.ZodString;
    devmode: z.ZodBoolean;
    pending: z.ZodBoolean;
    success: z.ZodBoolean;
    error: z.ZodNullable<z.ZodString>;
    metadata: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>>;
    cpu_time: z.ZodNullable<z.ZodNumber>;
    llm_cost: z.ZodNullable<z.ZodNumber>;
    llm_prompt_token_count: z.ZodNullable<z.ZodNumber>;
    llm_completion_token_count: z.ZodNullable<z.ZodNumber>;
    total_cost: z.ZodNullable<z.ZodNumber>;
    method: z.ZodNullable<z.ZodString>;
    url: z.ZodNullable<z.ZodString>;
    route_id: z.ZodNullable<z.ZodString>;
    thread_id: z.ZodNullable<z.ZodString>;
    timeline: z.ZodOptional<z.ZodNullable<z.ZodUnknown>>;
    user_data: z.ZodOptional<z.ZodNullable<z.ZodString>>;
}, z.core.$strip>>;
export declare const SessionListResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        deleted: z.ZodBoolean;
        deleted_at: z.ZodNullable<z.ZodString>;
        deleted_by: z.ZodNullable<z.ZodString>;
        start_time: z.ZodString;
        end_time: z.ZodNullable<z.ZodString>;
        duration: z.ZodNullable<z.ZodNumber>;
        org_id: z.ZodString;
        project_id: z.ZodString;
        deployment_id: z.ZodString;
        agent_ids: z.ZodArray<z.ZodString>;
        trigger: z.ZodString;
        env: z.ZodString;
        devmode: z.ZodBoolean;
        pending: z.ZodBoolean;
        success: z.ZodBoolean;
        error: z.ZodNullable<z.ZodString>;
        metadata: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>>;
        cpu_time: z.ZodNullable<z.ZodNumber>;
        llm_cost: z.ZodNullable<z.ZodNumber>;
        llm_prompt_token_count: z.ZodNullable<z.ZodNumber>;
        llm_completion_token_count: z.ZodNullable<z.ZodNumber>;
        total_cost: z.ZodNullable<z.ZodNumber>;
        method: z.ZodNullable<z.ZodString>;
        url: z.ZodNullable<z.ZodString>;
        route_id: z.ZodNullable<z.ZodString>;
        thread_id: z.ZodNullable<z.ZodString>;
        timeline: z.ZodOptional<z.ZodNullable<z.ZodUnknown>>;
        user_data: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, z.core.$strip>>;
}, z.core.$strip>], "success">;
export type SessionListResponse = z.infer<typeof SessionListResponseSchema>;
export type SessionList = z.infer<typeof SessionListResponse>;
export type Session = z.infer<typeof SessionSchema>;
export type SessionSortField = 'created' | 'updated' | 'duration' | 'startTime';
export declare const SessionListOptionsSchema: z.ZodObject<{
    count: z.ZodOptional<z.ZodNumber>;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    sort: z.ZodOptional<z.ZodEnum<{
        created: "created";
        updated: "updated";
        duration: "duration";
        startTime: "startTime";
    }>>;
    direction: z.ZodOptional<z.ZodEnum<{
        asc: "asc";
        desc: "desc";
    }>>;
    orgId: z.ZodOptional<z.ZodString>;
    projectId: z.ZodOptional<z.ZodString>;
    deploymentId: z.ZodOptional<z.ZodString>;
    trigger: z.ZodOptional<z.ZodString>;
    env: z.ZodOptional<z.ZodString>;
    devmode: z.ZodOptional<z.ZodBoolean>;
    success: z.ZodOptional<z.ZodBoolean>;
    threadId: z.ZodOptional<z.ZodString>;
    agentIdentifier: z.ZodOptional<z.ZodString>;
    startAfter: z.ZodOptional<z.ZodString>;
    startBefore: z.ZodOptional<z.ZodString>;
    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
}, z.core.$strip>;
export type SessionListOptions = z.infer<typeof SessionListOptionsSchema>;
/**
 * List sessions
 *
 * @param client
 * @param options filtering and pagination options
 * @returns
 */
export declare function sessionList(client: APIClient, options?: SessionListOptions): Promise<SessionList>;
//# sourceMappingURL=list.d.ts.map