import { OAuthKeysRotateResponseSchema } from "./types.js";
import { OAuthResponseError } from "./util.js";
export async function oauthKeysRotate(client) {
    const resp = await client.post('/oidc/keys/rotate', undefined, OAuthKeysRotateResponseSchema);
    if (resp.success) {
        return resp.data;
    }
    throw new OAuthResponseError({ message: resp.message });
}
//# sourceMappingURL=keys.js.map