import type { Body, HttpMethod } from './adapter.ts';
import { ServiceException } from './exception.ts';
export declare const buildUrl: (base: string, path: string, subpath?: string, query?: URLSearchParams) => string;
export declare function toServiceException(method: HttpMethod, url: string, response: Response): Promise<InstanceType<typeof ServiceException>>;
export declare function toPayload(data: unknown): Promise<[Body, string]>;
export declare function fromResponse<T>(response: Response): Promise<T>;
//# sourceMappingURL=_util.d.ts.map