import { z } from 'zod';
import { type APIClient } from '../api.ts';
export declare const ProjectDeleteRequestSchema: z.ZodObject<{
    ids: z.ZodArray<z.ZodString>;
}, z.core.$strip>;
export declare const ProjectDeleteResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodArray<z.ZodString>;
}, z.core.$strip>], "success">;
export declare function projectDelete(client: APIClient, ...ids: string[]): Promise<string[]>;
//# sourceMappingURL=delete.d.ts.map