import { CoderGitHubAccountListResponseSchema, CoderGitHubRepositoryListResponseSchema, } from "./types.js";
/**
 * Lists GitHub accounts available via the caller's GitHub App installations.
 */
export async function coderListGitHubAccounts(client) {
    return client.get('/hub/github/accounts', CoderGitHubAccountListResponseSchema);
}
/**
 * Lists repositories accessible under a specific GitHub account.
 */
export async function coderListGitHubRepos(client, params) {
    const path = `/hub/github/repos?accountId=${encodeURIComponent(params.accountId)}`;
    return client.get(path, CoderGitHubRepositoryListResponseSchema);
}
//# sourceMappingURL=github.js.map