import { z } from 'zod';
import { type APIClient } from '../api.ts';
export declare const SandboxEventInfoSchema: z.ZodObject<{
    eventId: z.ZodString;
    sandboxId: z.ZodString;
    type: z.ZodString;
    event: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    createdAt: z.ZodString;
}, z.core.$strip>;
export declare const SandboxEventListDataSchema: z.ZodObject<{
    events: z.ZodArray<z.ZodObject<{
        eventId: z.ZodString;
        sandboxId: z.ZodString;
        type: z.ZodString;
        event: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        createdAt: z.ZodString;
    }, z.core.$strip>>;
}, z.core.$strip>;
export declare const SandboxEventListResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        events: z.ZodArray<z.ZodObject<{
            eventId: z.ZodString;
            sandboxId: z.ZodString;
            type: z.ZodString;
            event: z.ZodRecord<z.ZodString, z.ZodUnknown>;
            createdAt: z.ZodString;
        }, z.core.$strip>>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export type SandboxEventInfo = z.infer<typeof SandboxEventInfoSchema>;
export declare const SandboxEventListParamsSchema: z.ZodObject<{
    sandboxId: z.ZodString;
    orgId: z.ZodOptional<z.ZodString>;
    limit: z.ZodOptional<z.ZodNumber>;
    direction: z.ZodOptional<z.ZodEnum<{
        asc: "asc";
        desc: "desc";
    }>>;
}, z.core.$strip>;
export type SandboxEventListParams = z.infer<typeof SandboxEventListParamsSchema>;
export type SandboxEventListResponse = z.infer<typeof SandboxEventListDataSchema>;
/**
 * Lists all events for a specific sandbox, ordered by creation time (oldest first by default).
 *
 * @param client - The API client to use for the request
 * @param params - Parameters including the sandbox ID, optional limit, and sort direction
 * @returns List of event information for the sandbox
 * @throws {SandboxResponseError} If the sandbox is not found or request fails
 */
export declare function sandboxEventList(client: APIClient, params: SandboxEventListParams): Promise<SandboxEventListResponse>;
//# sourceMappingURL=events.d.ts.map