import { OAuthOrgMembersResponseSchema } from "./types.js";
import { OAuthResponseError } from "./util.js";
export async function oauthOrgMembers(client) {
    const resp = await client.get('/oidc/org/members', OAuthOrgMembersResponseSchema);
    if (resp.success) {
        return resp.data;
    }
    throw new OAuthResponseError({ message: resp.message });
}
//# sourceMappingURL=members.js.map