import { z } from 'zod';
import { type APIClient } from '../api.ts';
declare const SandboxStatusDataSchema: z.ZodObject<{
    sandboxId: z.ZodString;
    status: z.ZodString;
    exitCode: z.ZodOptional<z.ZodNumber>;
}, z.core.$strip>;
export declare const SandboxGetStatusParamsSchema: z.ZodObject<{
    sandboxId: z.ZodString;
    orgId: z.ZodOptional<z.ZodString>;
    waitForStatus: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodArray<z.ZodString>]>>;
    waitMs: z.ZodOptional<z.ZodNumber>;
    signal: z.ZodOptional<z.ZodCustom<AbortSignal, AbortSignal>>;
}, z.core.$strip>;
export type SandboxGetStatusParams = z.infer<typeof SandboxGetStatusParamsSchema>;
export type SandboxStatusResult = z.infer<typeof SandboxStatusDataSchema>;
/**
 * Retrieves lightweight sandbox status (status + exitCode only).
 * Optimized for the sandbox run flow — backed by Redis for ~1ms response time.
 */
export declare function sandboxGetStatus(client: APIClient, params: SandboxGetStatusParams): Promise<SandboxStatusResult>;
export {};
//# sourceMappingURL=getStatus.d.ts.map