export declare const DbResponseError: {
    new (args?: ({
        database: string;
    } & {
        message?: string;
        cause?: unknown;
    }) | undefined): import("../../error.ts").RichError & {
        readonly _tag: "DbResponseError";
    } & Readonly<{
        database: string;
    }>;
    readonly defaultMessage?: string;
};
export declare const DbInvalidArgumentError: {
    new (args?: ({
        orgId?: string;
        region?: string;
        query?: string;
    } & {
        message?: string;
        cause?: unknown;
    }) | undefined): import("../../error.ts").RichError & {
        readonly _tag: "DbInvalidArgumentError";
    } & Readonly<{
        orgId?: string;
        region?: string;
        query?: string;
    }>;
    readonly defaultMessage?: string;
};
//# sourceMappingURL=util.d.ts.map